@@ -12,8 +12,8 @@ lazy_static! {
 }
 
 mod construction {
+    use fvm_ipld_encoding::RawBytes;
     use fvm_shared::address::{Address, BLS_PUB_LEN};
-    use fvm_shared::encoding::RawBytes;
     use fvm_shared::error::ExitCode;
     use fvm_shared::MethodNum;
 
@@ -59,9 +59,9 @@ mod construction {
 }
 
 mod verifiers {
+    use fvm_ipld_encoding::RawBytes;
     use fvm_shared::address::{Address, BLS_PUB_LEN};
     use fvm_shared::econ::TokenAmount;
-    use fvm_shared::encoding::RawBytes;
     use fvm_shared::error::ExitCode;
     use fvm_shared::{MethodNum, METHOD_SEND};
 
@@ -221,9 +221,9 @@ mod verifiers {
 }
 
 mod clients {
+    use fvm_ipld_encoding::RawBytes;
     use fvm_shared::address::{Address, BLS_PUB_LEN};
     use fvm_shared::econ::TokenAmount;
-    use fvm_shared::encoding::RawBytes;
     use fvm_shared::error::ExitCode;
     use fvm_shared::{MethodNum, METHOD_SEND};
 
